import { __extends } from "tslib";
import { PieChartSweepDirection_$type } from "./PieChartSweepDirection";
import { CalloutCollisionMode_$type } from "igniteui-react-core";
import { LegendEmptyValuesMode_$type } from "igniteui-react-core";
import { OthersCategoryType_$type } from "igniteui-react-core";
import { AxisRangeBufferMode_$type } from "./AxisRangeBufferMode";
import { RadialLabelMode_$type } from "igniteui-react-core";
import { CollisionAvoidanceType_$type } from "./CollisionAvoidanceType";
import { IgrRadialBaseChart } from "./igr-radial-base-chart";
import { ensureEnum, brushToString, stringToBrush, ensureBool, arrayFindByName } from "igniteui-react-core";
/**
 * Represents a base class for PieBase chart control that can plot scatter data
*/
var IgrDataPieBaseChart = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrDataPieBaseChart, _super);
    function IgrDataPieBaseChart(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrDataPieBaseChart.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "sliceLabelFormat", {
        /**
         * Gets or sets the label format for the slices.
        */
        get: function () {
            return this.i.ajp;
        },
        set: function (v) {
            this.i.ajp = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "sliceLabelFormatSpecifiers", {
        /**
         * Gets or sets the format specifiers to use with the labels for the slices.
        */
        get: function () {
            return this.i.ag3;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.ag3 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "legendSliceLabelFormat", {
        /**
         * Gets or sets the label format for the LegendSlices.
        */
        get: function () {
            return this.i.ai9;
        },
        set: function (v) {
            this.i.ai9 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "legendSliceLabelFormatSpecifiers", {
        /**
         * Gets or sets the format specifiers to use with the labels for the LegendSlices.
        */
        get: function () {
            return this.i.ag1;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.ag1 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "othersSliceLabelFormat", {
        /**
         * Gets or sets the label format for the OthersSlices.
        */
        get: function () {
            return this.i.aji;
        },
        set: function (v) {
            this.i.aji = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "othersSliceLabelFormatSpecifiers", {
        /**
         * Gets or sets the format specifiers to use with the labels for the OthersSlices.
        */
        get: function () {
            return this.i.ag2;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.ag2 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "legendOthersSliceLabelFormat", {
        /**
         * Gets or sets the label format for the LegendOthersSlices.
        */
        get: function () {
            return this.i.ai5;
        },
        set: function (v) {
            this.i.ai5 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "legendOthersSliceLabelFormatSpecifiers", {
        /**
         * Gets or sets the format specifiers to use with the labels for the LegendOthersSlices.
        */
        get: function () {
            return this.i.ag0;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.ag0 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "innerExtent", {
        /**
         * Defines the percentage of the maximum radius extent to leave blank at the center of the chart. Should be
         * a value between 0.0 and 1.0.
        */
        get: function () {
            return this.i.aia;
        },
        set: function (v) {
            this.i.aia = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "sweepDirection", {
        /**
         * Defines the percentage of the maximum radius extent to leave blank at the center of the chart. Should be
         * a value between 0.0 and 1.0.
        */
        get: function () {
            return this.i.ahh;
        },
        set: function (v) {
            this.i.ahh = ensureEnum(PieChartSweepDirection_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "sliceLabelPositionMode", {
        /**
         * Defines the positioning mode of the slice labels for the pie chart.
        */
        get: function () {
            return this.i.ag7;
        },
        set: function (v) {
            this.i.ag7 = ensureEnum(CalloutCollisionMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "lightSliceLabelColor", {
        /**
         * Gets or sets the light color to use for slice labels.
        */
        get: function () {
            return brushToString(this.i.akh);
        },
        set: function (v) {
            this.i.akh = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "darkSliceLabelColor", {
        /**
         * Gets or sets the Dark color to use for slice labels.
        */
        get: function () {
            return brushToString(this.i.akg);
        },
        set: function (v) {
            this.i.akg = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "valueMemberPath", {
        /**
         * Gets or sets the overridden value member path to use.
        */
        get: function () {
            return this.i.aj5;
        },
        set: function (v) {
            this.i.aj5 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "legendLabelMemberPath", {
        /**
         * Gets or sets the legend label member path to use.
        */
        get: function () {
            return this.i.ai3;
        },
        set: function (v) {
            this.i.ai3 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "legendEmptyValuesMode", {
        get: function () {
            return this.i.ahb;
        },
        set: function (v) {
            this.i.ahb = ensureEnum(LegendEmptyValuesMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "othersCategoryType", {
        /**
         * Gets or sets whether to use numeric or percent-based threshold value.
        */
        get: function () {
            return this.i.ahf;
        },
        set: function (v) {
            this.i.ahf = ensureEnum(OthersCategoryType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "othersCategoryThreshold", {
        /**
         * Gets or sets the threshold value that determines if slices are grouped into the Others slice.
        */
        get: function () {
            return this.i.aib;
        },
        set: function (v) {
            this.i.aib = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "othersCategoryText", {
        /**
         * Gets or sets the label of the Others slice.
        */
        get: function () {
            return this.i.aje;
        },
        set: function (v) {
            this.i.aje = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "labelMemberPath", {
        /**
         * Gets or sets the overridden value member path to use.
        */
        get: function () {
            return this.i.ai0;
        },
        set: function (v) {
            this.i.ai0 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "valueAxisFavorLabellingScaleEnd", {
        /**
         * Gets or sets whether the axis should favor emitting a label at the end of the scale.
        */
        get: function () {
            return this.i.ahw;
        },
        set: function (v) {
            this.i.ahw = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "valueAxisAutoRangeBufferMode", {
        /**
         * Gets or sets how the numeric axis will adjust its range buffer to less closely fix the data from the series.
        */
        get: function () {
            return this.i.ag5;
        },
        set: function (v) {
            this.i.ag5 = ensureEnum(AxisRangeBufferMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "angleAxisInterval", {
        /**
         * Gets or sets the frequency of displayed labels along the X-axis.
         * Gets or sets the set value is a factor that determines which labels will be hidden. For example, an interval of 2 will display every other label.
        */
        get: function () {
            return this.i.ah8;
        },
        set: function (v) {
            this.i.ah8 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "angleAxisMinorInterval", {
        /**
         * Gets or sets the frequency of displayed minor lines along the X-axis.
         * Gets or sets the set value is a factor that determines how the minor lines will be displayed.
        */
        get: function () {
            return this.i.ah9;
        },
        set: function (v) {
            this.i.ah9 = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "valueAxisInterval", {
        /**
         * Gets or sets the distance between each label and grid line along the Y-axis.
        */
        get: function () {
            return this.i.aig;
        },
        set: function (v) {
            this.i.aig = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "valueAxisIsLogarithmic", {
        /**
         * Gets or sets whether the Y-axis should use a logarithmic scale instead of a linear one.
         * Since log(-1) is imaginary and log(0) is undefined, it is recommended to enable this property only when the Y-axis minimum is greater than zero.
        */
        get: function () {
            return this.i.ahx;
        },
        set: function (v) {
            this.i.ahx = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "valueAxisLogarithmBase", {
        /**
         * Gets or sets the base value to use in the log function when mapping the position of data items along the Y-axis.
         * This property is effective only when ValueAxisIsLogarithmic is true.
        */
        get: function () {
            return this.i.ail;
        },
        set: function (v) {
            this.i.ail = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "valueAxisMinimumValue", {
        /**
         * Gets or sets the data value corresponding to the minimum value of the Y-axis.
        */
        get: function () {
            return this.i.aii;
        },
        set: function (v) {
            this.i.aii = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "valueAxisMaximumValue", {
        /**
         * Gets or sets the data value corresponding to the maximum value of the Y-axis.
        */
        get: function () {
            return this.i.aih;
        },
        set: function (v) {
            this.i.aih = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "valueAxisMinorInterval", {
        /**
         * Gets or sets the frequency of displayed minor lines along the Y-axis.
        */
        get: function () {
            return this.i.aij;
        },
        set: function (v) {
            this.i.aij = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "valueAxisActualMinimum", {
        /**
         * Gets the current minimum value for the Y-axis.
        */
        get: function () {
            return this.i.aif;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "valueAxisActualMaximum", {
        /**
         * Gets the current maximum value for the Y-axis.
        */
        get: function () {
            return this.i.aie;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "radiusExtent", {
        /**
         * Gets or sets the extent of the chart's radius. Value between 0 and 1.
        */
        get: function () {
            return this.i.aic;
        },
        set: function (v) {
            this.i.aic = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "startAngle", {
        /**
         * Gets or sets the start angle to use for the pie chart measured in degrees from the positive x axis.
        */
        get: function () {
            return this.i.aid;
        },
        set: function (v) {
            this.i.aid = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "sliceLabelContentSeparator", {
        /**
         * Gets or sets the label of the Others slice.
        */
        get: function () {
            return this.i.ajn;
        },
        set: function (v) {
            this.i.ajn = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "sliceLabelContentMode", {
        /**
         * Gets or sets the label of the Others slice.
        */
        get: function () {
            return this.i.ahn;
        },
        set: function (v) {
            this.i.ahn = ensureEnum(RadialLabelMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "legendSliceLabelContentMode", {
        /**
         * Gets or sets the label of the Others slice.
        */
        get: function () {
            return this.i.ahm;
        },
        set: function (v) {
            this.i.ahm = ensureEnum(RadialLabelMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "angleAxisFavorLabellingScaleEnd", {
        /**
         * Gets or sets whether to favor labelling the end of the scale.
        */
        get: function () {
            return this.i.aht;
        },
        set: function (v) {
            this.i.aht = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "valueAxisAbbreviateLargeNumbers", {
        /**
         * Gets or sets whether the large numbers on the Y-axis labels are abbreviated.
        */
        get: function () {
            return this.i.ahv;
        },
        set: function (v) {
            this.i.ahv = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDataPieBaseChart.prototype, "markerCollision", {
        /**
         * Gets or sets collision avoidance between markers on series that support this behaviour.
        */
        get: function () {
            return this.i.ag9;
        },
        set: function (v) {
            this.i.ag9 = ensureEnum(CollisionAvoidanceType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    IgrDataPieBaseChart.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.sliceLabelFormatSpecifiers != null && arrayFindByName(this.sliceLabelFormatSpecifiers, name)) {
            return arrayFindByName(this.sliceLabelFormatSpecifiers, name);
        }
        if (this.legendSliceLabelFormatSpecifiers != null && arrayFindByName(this.legendSliceLabelFormatSpecifiers, name)) {
            return arrayFindByName(this.legendSliceLabelFormatSpecifiers, name);
        }
        if (this.othersSliceLabelFormatSpecifiers != null && arrayFindByName(this.othersSliceLabelFormatSpecifiers, name)) {
            return arrayFindByName(this.othersSliceLabelFormatSpecifiers, name);
        }
        if (this.legendOthersSliceLabelFormatSpecifiers != null && arrayFindByName(this.legendOthersSliceLabelFormatSpecifiers, name)) {
            return arrayFindByName(this.legendOthersSliceLabelFormatSpecifiers, name);
        }
        return null;
    };
    return IgrDataPieBaseChart;
}(IgrRadialBaseChart));
export { IgrDataPieBaseChart };
